@@ -103,7 +103,7 @@ namespace Ogre {
             /* Bytes per element */
             1,
             /* Flags */
-            PFF_HASALPHA | PFF_NATIVEENDIAN,
+            PFF_HASALPHA,
             /* Component type and count */
             PCT_BYTE, 1,
             /* rbits, gbits, bbits, abits */
@@ -1528,6 +1528,18 @@ namespace Ogre {
             /* Masks and shifts */
             0, 0, 0, 0, 0, 0, 0, 0
         },
+        {"PF_DEPTH24_STENCIL8",
+            /* Bytes per element */
+            4,
+            /* Flags */
+            PFF_LUMINANCE | PFF_DEPTH | PFF_NATIVEENDIAN,
+            /* Component type and count */
+            PCT_UINT, 1,
+            /* rbits, gbits, bbits, abits */
+            24, 0, 0, 0,
+            /* Masks and shifts */
+            0, 0, 0, 0, 0, 0, 0, 0
+        },
     };
     /** @} */
     /** @} */
