@@ -963,18 +963,13 @@ namespace Ogre {
     //---------------------------------------------------------------------
     const String& RenderSystem::_getDefaultViewportMaterialScheme( void ) const
     {
-#ifdef RTSHADER_SYSTEM_BUILD_CORE_SHADERS   
-        if ( !(getCapabilities()->hasCapability(Ogre::RSC_FIXED_FUNCTION)) )
+#ifdef RTSHADER_SYSTEM_BUILD_CORE_SHADERS
+        if (!getCapabilities()->hasCapability(RSC_FIXED_FUNCTION))
         {
-            // I am returning the exact value for now - I don't want to add dependency for the RTSS just for one string  
-            static const String ShaderGeneratorDefaultScheme = "ShaderGeneratorDefaultScheme";
-            return ShaderGeneratorDefaultScheme;
+            return MSN_SHADERGEN;
         }
-        else
 #endif
-        {
-            return MaterialManager::DEFAULT_SCHEME_NAME;
-        }
+        return MSN_DEFAULT;
     }
     //---------------------------------------------------------------------
     Ogre::HardwareVertexBufferSharedPtr RenderSystem::getGlobalInstanceVertexBuffer() const
