@@ -367,6 +367,10 @@ bool AssimpLoader::_load(const char* name, Assimp::Importer& importer, Mesh* mes
         flags |= aiProcess_JoinIdenticalVertices;
 
     flags |= options.postProcessSteps;
+
+    if((flags & (aiProcess_GenSmoothNormals | aiProcess_GenNormals)) != aiProcess_GenNormals)
+        flags &= ~aiProcess_GenNormals; // prefer smooth normals
+
     importer.SetPropertyFloat("PP_GSN_MAX_SMOOTHING_ANGLE", options.maxEdgeAngle);
     const aiScene* scene = importer.ReadFile(name, flags);
 
@@ -815,12 +819,12 @@ void AssimpLoader::grabBoneNamesFromNode(const aiScene* mScene, const aiNode* pN
                         aiNode* node = mScene->mRootNode->FindNode(pAIBone->mName.data);
                         while (node)
                         {
-                            if (node->mName.data == pNode->mName.data)
+                            if (node->mName == pNode->mName)
                             {
                                 flagNodeAsNeeded(node->mName.data);
                                 break;
                             }
-                            if (node->mName.data == pNode->mParent->mName.data)
+                            if (node->mName == pNode->mParent->mName)
                             {
                                 flagNodeAsNeeded(node->mName.data);
                                 break;
@@ -976,7 +980,6 @@ MaterialPtr AssimpLoader::createMaterial(const aiMaterial* mat, const Ogre::Stri
     }
 
 #ifdef OGRE_BUILD_COMPONENT_RTSHADERSYSTEM
-    auto& dstScheme = RTShader::ShaderGenerator::DEFAULT_SCHEME_NAME;
     auto shaderGen = RTShader::ShaderGenerator::getSingletonPtr();
 
     if(!shaderGen)
@@ -989,8 +992,8 @@ MaterialPtr AssimpLoader::createMaterial(const aiMaterial* mat, const Ogre::Stri
             LogManager::getSingleton().logMessage("Found normal map: " + String(path.data));
         }
 
-        shaderGen->createShaderBasedTechnique(omat->getTechnique(0), dstScheme);
-        auto rs = shaderGen->getRenderState(dstScheme, *omat, 0);
+        shaderGen->createShaderBasedTechnique(omat->getTechnique(0), MSN_SHADERGEN);
+        auto rs = shaderGen->getRenderState(MSN_SHADERGEN, *omat, 0);
         auto srs = shaderGen->createSubRenderState("NormalMap");
 
         StringUtil::splitFilename(String(path.data), basename, outPath);
@@ -1005,8 +1008,8 @@ MaterialPtr AssimpLoader::createMaterial(const aiMaterial* mat, const Ogre::Stri
             LogManager::getSingleton().logMessage("Found metal roughness map: " + String(path.data));
         }
 
-        shaderGen->createShaderBasedTechnique(omat->getTechnique(0), dstScheme);
-        auto rs = shaderGen->getRenderState(dstScheme, *omat, 0);
+        shaderGen->createShaderBasedTechnique(omat->getTechnique(0), MSN_SHADERGEN);
+        auto rs = shaderGen->getRenderState(MSN_SHADERGEN, *omat, 0);
         auto srs = shaderGen->createSubRenderState("CookTorranceLighting");
 
         StringUtil::splitFilename(String(path.data), basename, outPath);
