@@ -12,63 +12,56 @@ This source file is part of OGRE
 (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2006 Torus Knot Software Ltd
-Also see acknowledgements in Readme.html
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
-This program is free software; you can redistribute it and/or modify it under
-the terms of the GNU Lesser General Public License as published by the Free Software
-Foundation; either version 2 of the License, or (at your option) any later
-version.
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
 
-This program is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
 
-You should have received a copy of the GNU Lesser General Public License along with
-this program; if not, write to the Free Software Foundation, Inc., 59 Temple
-Place - Suite 330, Boston, MA 02111-1307, USA, or go to
-http://www.gnu.org/copyleft/lesser.txt.
-
-You may alternatively use this source under the terms of a specific version of
-the OGRE Unrestricted License provided you have obtained such a license from
-Torus Knot Software Ltd.
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+THE SOFTWARE.
 -----------------------------------------------------------------------------
 */
 
 #ifndef OCTREESCENEMANAGER_H
 #define OCTREESCENEMANAGER_H
 
-#include "OgreTerrainPrerequisites.h"
+#include "OgreOctreePrerequisites.h"
 #include "OgreSceneManager.h"
-#include "OgreRenderOperation.h"
-#include "OgreSphere.h"
 
 #include <list>
 #include <algorithm>
 
-#include <OgreOctree.h>
+#include "OgreOctree.h"
 
 
 namespace Ogre
 {
-
+/** \addtogroup Plugins Plugins
+*  @{
+*/
+/** \addtogroup Octree OctreeSceneManager
+* Octree datastructure for managing scene nodes.
+*  @{
+*/
 class OctreeNode;
-
 class OctreeCamera;
-class OctreeIntersectionSceneQuery;
-class OctreeRaySceneQuery;
-class OctreeSphereSceneQuery;
-class OctreeAxisAlignedBoxSceneQuery;
-class OctreePlaneBoundedVolumeListSceneQuery;
-
-
-typedef std::list < WireBoundingBox * > BoxList;
-typedef std::list < unsigned long > ColorList;
-//typedef std::list < SceneNode * > SceneNodeList;
 
+typedef std::list< WireBoundingBox * > BoxList;
+typedef std::list< unsigned long > ColorList;
 
 /** Specialized SceneManager that divides the geometry into an octree in order to facilitate spatial queries.
-@remarks
 */
 
 class _OgreOctreePluginExport OctreeSceneManager : public SceneManager
@@ -88,8 +81,8 @@ public:
     /** Standard destructor */
     ~OctreeSceneManager();
 
-	/// @copydoc SceneManager::getTypeName
-	const String& getTypeName(void) const;
+    /// @copydoc SceneManager::getTypeName
+    const String& getTypeName(void) const;
 
     /** Initializes the manager to the given box and depth.
     */
@@ -111,7 +104,7 @@ public:
     virtual void _updateSceneGraph( Camera * cam );
     /** Recurses through the octree determining which nodes are visible. */
     virtual void _findVisibleObjects ( Camera * cam, 
-		VisibleObjectsBoundsInfo* visibleBounds, bool onlyShadowCasters );
+        VisibleObjectsBoundsInfo* visibleBounds, bool onlyShadowCasters );
 
     /** Alerts each unculled object, notifying it that it will be drawn.
      * Useful for doing calculations only on nodes that will be drawn, prior
@@ -120,13 +113,13 @@ public:
     virtual void _alertVisibleObjects( void );
 
     /** Walks through the octree, adding any visible objects to the render queue.
-    @remarks
+
     If any octant in the octree if completely within the view frustum,
     all subchildren are automatically added with no visibility tests.
     */
     void walkOctree( OctreeCamera *, RenderQueue *, Octree *, 
-		VisibleObjectsBoundsInfo* visibleBounds, bool foundvisible, 
-		bool onlyShadowCasters);
+        VisibleObjectsBoundsInfo* visibleBounds, bool foundvisible, 
+        bool onlyShadowCasters);
 
     /** Checks the given OctreeNode, and determines if it needs to be moved
     * to a different octant.
@@ -141,22 +134,22 @@ public:
     /** Recurses the octree, adding any nodes intersecting with the box into the given list.
     It ignores the exclude scene node.
     */
-    void findNodesIn( const AxisAlignedBox &box, std::list < SceneNode * > &list, SceneNode *exclude = 0 );
+    void findNodesIn( const AxisAlignedBox &box, std::list< SceneNode * > &list, SceneNode *exclude = 0 );
 
     /** Recurses the octree, adding any nodes intersecting with the sphere into the given list.
     It ignores the exclude scene node.
     */
-    void findNodesIn( const Sphere &sphere, std::list < SceneNode * > &list, SceneNode *exclude = 0 );
+    void findNodesIn( const Sphere &sphere, std::list< SceneNode * > &list, SceneNode *exclude = 0 );
 
     /** Recurses the octree, adding any nodes intersecting with the volume into the given list.
       It ignores the exclude scene node.
       */
-    void findNodesIn( const PlaneBoundedVolume &volume, std::list < SceneNode * > &list, SceneNode *exclude=0 );
+    void findNodesIn( const PlaneBoundedVolume &volume, std::list< SceneNode * > &list, SceneNode *exclude=0 );
 
     /** Recurses the octree, adding any nodes intersecting with the ray into the given list.
       It ignores the exclude scene node.
       */
-    void findNodesIn( const Ray &ray, std::list < SceneNode * > &list, SceneNode *exclude=0 );
+    void findNodesIn( const Ray &ray, std::list< SceneNode * > &list, SceneNode *exclude=0 );
 
     /** Sets the box visibility flag */
     void setShowBoxes( bool b )
@@ -164,17 +157,11 @@ public:
         mShowBoxes = b;
     };
 
-    void setLooseOctree( bool b )
-    {
-        mLoose = b;
-    };
-
-
     /** Resizes the octree to the given size */
     void resize( const AxisAlignedBox &box );
 
     /** Sets the given option for the SceneManager
-               @remarks
+
         Options are:
         "Size", AxisAlignedBox *;
         "Depth", int *;
@@ -183,7 +170,7 @@ public:
 
     virtual bool setOption( const String &, const void * );
     /** Gets the given option for the Scene Manager.
-        @remarks
+
         See setOption
     */
     virtual bool getOption( const String &, void * );
@@ -193,17 +180,16 @@ public:
     /** Overridden from SceneManager */
     void clearScene(void);
 
-    AxisAlignedBoxSceneQuery* createAABBQuery(const AxisAlignedBox& box, unsigned long mask);
-    SphereSceneQuery* createSphereQuery(const Sphere& sphere, unsigned long mask);
-    PlaneBoundedVolumeListSceneQuery* createPlaneBoundedVolumeQuery(const PlaneBoundedVolumeList& volumes, unsigned long mask);
-    RaySceneQuery* createRayQuery(const Ray& ray, unsigned long mask);
-    IntersectionSceneQuery* createIntersectionQuery(unsigned long mask);
-
+    AxisAlignedBoxSceneQuery* createAABBQuery(const AxisAlignedBox& box, uint32 mask);
+    SphereSceneQuery* createSphereQuery(const Sphere& sphere, uint32 mask);
+    PlaneBoundedVolumeListSceneQuery* createPlaneBoundedVolumeQuery(const PlaneBoundedVolumeList& volumes, uint32 mask);
+    RaySceneQuery* createRayQuery(const Ray& ray, uint32 mask);
+    IntersectionSceneQuery* createIntersectionQuery(uint32 mask);
 
 protected:
 
 
-    NodeList mVisible;
+    Octree::NodeList mVisible;
 
     /// The root octree
     Octree *mOctree;
@@ -222,9 +208,6 @@ protected:
     /// Boxes visibility flag
     bool mShowBoxes;
 
-
-    bool mLoose;
-
     Real mCorners[ 24 ];
     static unsigned long mColors[ 8 ];
     static unsigned short mIndexes[ 24 ];
@@ -237,18 +220,18 @@ protected:
 class OctreeSceneManagerFactory : public SceneManagerFactory
 {
 protected:
-	void initMetaData(void) const;
+    void initMetaData(void) const;
 public:
-	OctreeSceneManagerFactory() {}
-	~OctreeSceneManagerFactory() {}
-	/// Factory type name
-	static const String FACTORY_TYPE_NAME;
-	SceneManager* createInstance(const String& instanceName);
-	void destroyInstance(SceneManager* instance);
+    OctreeSceneManagerFactory() {}
+    ~OctreeSceneManagerFactory() {}
+    /// Factory type name
+    static const String FACTORY_TYPE_NAME;
+    SceneManager* createInstance(const String& instanceName);
 };
 
 
-
+/** @} */
+/** @} */
 }
 
 #endif
