@@ -323,42 +323,18 @@ namespace Ogre
 
     SceneNode* PCZSceneManager::createSceneNodeImpl(void)
     {
-        return OGRE_NEW PCZSceneNode(this);
+        auto ret = new PCZSceneNode(this);
+        // create any zone-specific data necessary
+        createZoneSpecificNodeData(ret);
+        return ret;
     }
 
     SceneNode* PCZSceneManager::createSceneNodeImpl(const String& name)
     {
-        return OGRE_NEW PCZSceneNode(this, name);
-    }
-
-    SceneNode * PCZSceneManager::createSceneNode( void )
-    {
-        SceneNode * on = createSceneNodeImpl();
-        mSceneNodes.push_back(on);
-
+        auto ret = new PCZSceneNode(this, name);
         // create any zone-specific data necessary
-        createZoneSpecificNodeData((PCZSceneNode*)on);
-        // return pointer to the node
-        return on;
-    }
-
-    SceneNode * PCZSceneManager::createSceneNode( const String &name )
-    {
-        // Check name not used
-        if (hasSceneNode(name))
-        {
-            OGRE_EXCEPT(
-                Exception::ERR_DUPLICATE_ITEM,
-                "A scene node with the name " + name + " already exists",
-                "PCZSceneManager::createSceneNode" );
-        }
-        SceneNode * on = createSceneNodeImpl( name );
-        mSceneNodes.push_back(on);
-
-        // create any zone-specific data necessary
-        createZoneSpecificNodeData((PCZSceneNode*)on);
-        // return pointer to the node
-        return on;
+        createZoneSpecificNodeData(ret);
+        return ret;
     }
 
     // Create a camera for the scene
@@ -1442,11 +1418,5 @@ namespace Ogre
     {
         return OGRE_NEW PCZSceneManager(instanceName);
     }
-    //-----------------------------------------------------------------------
-    void PCZSceneManagerFactory::destroyInstance(SceneManager* instance)
-    {
-        OGRE_DELETE instance;
-    }
-
 
 }
