@@ -66,7 +66,7 @@ GLGpuProgram::~GLGpuProgram()
     unload(); 
 }
 
-bool GLGpuProgram::isAttributeValid(VertexElementSemantic semantic, uint index)
+bool GLGpuProgramBase::isAttributeValid(VertexElementSemantic semantic, uint index)
 {
     // default implementation
     switch(semantic)
@@ -87,19 +87,6 @@ bool GLGpuProgram::isAttributeValid(VertexElementSemantic semantic, uint index)
     return false;
 }
 
-//-----------------------------------------------------------------------------
-size_t GLGpuProgram::calculateSize(void) const
-{
-    size_t memSize = 0;
-
-    // Delegate Names
-    memSize += sizeof(GLuint);
-    memSize += sizeof(GLenum);
-    memSize += GpuProgram::calculateSize();
-    
-    return memSize;
-}
-
 GLArbGpuProgram::GLArbGpuProgram(ResourceManager* creator, const String& name, 
     ResourceHandle handle, const String& group, bool isManual, 
     ManualResourceLoader* loader) 
@@ -132,7 +119,7 @@ void GLArbGpuProgram::bindProgramParameters(GpuProgramParametersSharedPtr params
     GLenum type = getProgramType();
     
     // only supports float constants
-    GpuLogicalBufferStructPtr floatStruct = params->getFloatLogicalBufferStruct();
+    GpuLogicalBufferStructPtr floatStruct = params->getLogicalBufferStruct();
 
     for (GpuLogicalIndexUseMap::const_iterator i = floatStruct->map.begin();
         i != floatStruct->map.end(); ++i)
